<template>
  <div
    v-empty="nopermission"
    class="rc-cont"
    xs-empty-icon="nopermission"
    xs-empty-text="暂无权限">
    <el-table
      :data="list"
      :height="tableHeight"
      :header-cell-style="headerRowStyle"
      :cell-style="cellStyle"
      style="width: 100%;border: 1px solid #E6E6E6;"
      @row-click="handleRowClick">
      <el-table-column
        v-for="(item, index) in fieldList"
        :key="index"
        :prop="item.prop"
        :formatter="fieldFormatter"
        :label="item.label"
        show-overflow-tooltip>
        <template
          slot="header"
          slot-scope="scope">
          <div class="table-head-name">{{ scope.column.label }}</div>
        </template>
       </el-table-column>
    </el-table>
    <div class="p-contianer" v-show='total>0'>
        <el-pagination
          :current-page="currentPage"
          :page-sizes="pageSizes"
          :page-size.sync="pageSize"
          :total="total"
          class="p-bar"
          layout="total, sizes, prev, pager, next, jumper"
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"/>
      </div>

    <c-r-m-full-screen-detail
      :visible.sync="showFullDetail"
      :id="contractId"
      crm-type="contract"/>
    <c-r-m-create-view
      v-if="isCreate"
      :action="createActionInfo"
      crm-type="contract"
      @save-success="createSaveSuccess"
      @hiden-view="isCreate=false"/>
  </div>
</template>

<script type="text/javascript">
import loading from '../mixins/loading'
import CRMCreateView from './CRMCreateView'
import { GetCustomerOrderList } from '@/api/customermanagement/customerManage'
import { GetAutoSalesChanceLogList } from '@/api/customermanagement/business'
// import { moneyFormat } from '@/utils'

export default {
  name: 'RelativeApproval', // 相关商机流转跟踪记录  可能再很多地方展示 放到客户管理目录下
  components: {
    CRMFullScreenDetail: () => import('./CRMFullScreenDetail.vue'),
    CRMCreateView
  },
  mixins: [loading],
  props: {
    /** 模块ID */
    id: [String, Number],
    /** 没有值就是全部类型 有值就是当个类型 */
    crmType: {
      type: String,
      default: ''
    },
    /** 是公海 默认是客户 */
    isSeas: {
      type: Boolean,
      default: false
    },
    /** 联系人人下 新建商机 需要联系人里的客户信息  合同下需要客户和商机信息 */
    detail: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data () {
    return {
      nopermission: false,
      list: [],
      fieldList: [],
      tableHeight: '400px',
      showFullDetail: false,
      isCreate: false, // 控制新建
      contractId: '', // 查看全屏联系人详情的 ID
      // 创建的相关信息
      createActionInfo: { type: 'relative', crmType: this.crmType, data: {} },
      total: 0,
      currentPage: 1,
      pageSize: 10,
      pageSizes: [10, 30, 60, 100]
    }
  },
  computed: {},
  watch: {
    id: function (val) {
      this.list = []
      this.getDetail()
    }
  },
  mounted () {
    this.getDetail()
  },
  activated: function () {},
  deactivated: function () {},
  methods: {
    handleSizeChange (newSize) {
      this.pageSize = newSize
      this.getDetail()
    },
    handleCurrentChange (newPage) {
      this.getDetail()
    },
    /** 格式化字段 */
    fieldFormatter (row, column) {
      // 如果需要格式化
      return row[column.property] || '--'
    },
    getFieldList () {
      this.fieldList.push(
        { prop: 'AddTime', label: '商机状态跟踪记录时间' },
        { prop: 'ExpireTime', label: '商机有效期' },
        { prop: 'Status', label: '商机审批状态' }
      )
    },
    getDetail () {
      this.loading = true
      const request = {
        customer: GetCustomerOrderList,
        businessCustomer: GetCustomerOrderList,
        business: GetAutoSalesChanceLogList,
        businessChances: GetAutoSalesChanceLogList
      }[this.crmType]
      const params = {}
      params['Id'] = this.id
      params['PageSize'] = this.pageSize
      params['PageIndex'] = this.currentPage
      request(params)
        .then(res => {
          if (this.fieldList.length === 0) {
            this.getFieldList()
          }
          this.nopermission = false
          this.loading = false
          this.list = res.data.Result.List
          this.total = res.data.Result.Count
        })
        .catch(data => {
          if (data.code === 102) {
            this.nopermission = true
          }
          this.loading = false
        })
    },

    /**
     * 对应的状态名
     */
    getStatusName (status) {
      if (status === 1) {
        return '已盖章'
      } else if (status === 2) {
        return '未盖章'
      }
      return '暂无'
    },
    getSealName (type) {
      if (type === 0) {
        return '暂无'
      } else if (type === 1) {
        return '合同章'
      } else if (type === 2) {
        return '公章'
      }
      return '暂无'
    },
    getAuditStatus (type) {
      if (type === 1) {
        return '待审核'
      } else if (type === 2) {
        return '审核成功'
      } else if (type === 3) {
        return '审核失败'
      }
      return '暂无'
    },
    getSwitch (type) {
      console.log(type)
      if (type === false) {
        return '否'
      } else if (type === true) {
        return '是'
      }
      return '暂无'
    },
    // 当某一行被点击时会触发该事件
    handleRowClick (row, column, event) {
      // this.contractId = row.contractId
      // this.showFullDetail = true
    },
    /** 通过回调控制表头style */
    headerRowStyle ({ row, column, rowIndex, columnIndex }) {
      return { textAlign: 'left' }
    },
    /** 通过回调控制style */
    cellStyle ({ row, column, rowIndex, columnIndex }) {
      return { textAlign: 'left' }
    },
    /** 新建 */
    createClick () {
      /** 客户 和 商机 下新建合同 */
      if (this.crmType === 'business') {
        this.createActionInfo.data['customer'] = this.detail
        this.createActionInfo.data['business'] = this.detail
      } else if (this.crmType === 'customer') {
        this.createActionInfo.data['customer'] = this.detail
      }
      this.isCreate = true
    },
    createSaveSuccess () {
      this.getDetail()
    }
  }
}
</script>
<style lang="scss" scoped>
@import '../styles/relativecrm.scss';
</style>
